/* AlignMatch.java
 *
 * created: Wed Jul 14 1999
 *
 * This file is part of Artemis
 *
 * Copyright (C) 1999,2000  Genome Research Limited
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Header: /nfs/disk222/yeastpub/Repository/powmap/diana/AlignMatch.java,v 1.2 2000/04/05 10:37:13 kmr Exp $
 */

package diana;

/**
 *  Each object of this class represents a single match from an alignment.
 *
 *  @author Kim Rutherford
 *  @version $Id: AlignMatch.java,v 1.2 2000/04/05 10:37:13 kmr Exp $
 **/

public class AlignMatch {
  /**
   *  Create a new AlignMatch object.
   *  @param score the score for this match, which should be -1 if and only if
   *    this match has no score.  The parameter must be >= -1.
   **/
  public AlignMatch (final int first_sequence_start,
                     final int first_sequence_end,
                     final int second_sequence_start,
                     final int second_sequence_end,
                     final int score) {
    this.first_sequence_start  = first_sequence_start;
    this.first_sequence_end    = first_sequence_end;
    this.second_sequence_start = second_sequence_start;
    this.second_sequence_end   = second_sequence_end;
    this.score                 = score;
  }


  /**
   *  Return the start (base) of the match in the first sequence.
   **/
  public int getFirstSequenceStart () {
    return first_sequence_start;
  }

  /**
   *  Return the end (base) of the match in the first sequence.
   **/
  public int getFirstSequenceEnd () {
    return first_sequence_end;
  }

  /**
   *  Return the start (base) of the match in the second sequence.
   **/
  public int getSecondSequenceStart () {
    return second_sequence_start;
  }

  /**
   *  Return the end (base) of the match in the second sequence.
   **/
  public int getSecondSequenceEnd () {
    return second_sequence_end;
  }

  /**
   *  Return the score of this match.
   **/
  public int getScore () {
    return score;
  }

  /**
   *  The start of the match in the first sequence.
   **/
  private int first_sequence_start = -1;

  /**
   *  The end of the match in the first sequence.
   **/
  private int first_sequence_end = -1;

  /**
   *  The start of the match in the second sequence.
   **/
  private int second_sequence_start = -1;

  /**
   *  The end of the match in the second sequence.
   **/
  private int second_sequence_end = -1;

  /**
   *  The score that was passed to the constructor.
   **/
  private int score = -1;
}
