/* MSPcrunchComparisonData.java
 *
 * created: Tue Apr  4 2000
 *
 * This file is part of Artemis
 * 
 * Copyright (C) 2000  Genome Research Limited
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * $Header: /nfs/disk222/yeastpub/Repository/powmap/diana/MSPcrunchComparisonData.java,v 1.1 2000/04/05 10:34:33 kmr Exp $
 */

package diana;

import java.io.*;
import java.util.StringTokenizer;
import java.util.Vector;

import uk.ac.sanger.pathogens.embl.LinePushBackReader;

/**
 *  This class implements the ComparisonData interface for MSPcrunch -x
 *  output.
 *
 *  @author Kim Rutherford <kmr@sanger.ac.uk>
 *  @version $Id: MSPcrunchComparisonData.java,v 1.1 2000/04/05 10:34:33 kmr Exp $
 **/

public class MSPcrunchComparisonData
    implements ComparisonData {
  /**
   *  Create a new MSPcrunchComparisonData object by reading from the given
   *  LinePushBackReader.
   **/
  public MSPcrunchComparisonData (final LinePushBackReader stream)
      throws IOException {

    final Vector align_match_vector = new Vector ();

    while (true) {
      final String line = stream.readLine ();

      if (line == null) {
        break;
      }

      final StringTokenizer tokenizer = new StringTokenizer (line, " ");

      final String score_token = tokenizer.nextToken ();
      final String percent_ident_token = tokenizer.nextToken ();
      final String q_start_token = tokenizer.nextToken ();
      final String q_end_token = tokenizer.nextToken ();

      tokenizer.nextToken ();

      final String s_start_token = tokenizer.nextToken ();
      final String s_end_token = tokenizer.nextToken ();

      try {
        final int score   = Integer.valueOf (score_token).intValue ();
        final int percent_ident = (int)(Float.valueOf (percent_ident_token).floatValue ());
        final int q_start = Integer.valueOf (q_start_token).intValue ();
        final int q_end   = Integer.valueOf (q_end_token).intValue ();
        final int s_start = Integer.valueOf (s_start_token).intValue ();
        final int s_end   = Integer.valueOf (s_end_token).intValue ();

        if (percent_ident > max_score) {
          max_score = percent_ident;
        }

        if (percent_ident < min_score) {
          min_score = percent_ident;
        }

        final AlignMatch new_match =
          new AlignMatch (q_start, q_end, s_start, s_end, percent_ident);

        align_match_vector.addElement (new_match);
      } catch (NumberFormatException e) {
        System.err.println ("failed to parse a number from this string: " +
                            e.getMessage ());
        System.exit (1);
      }

    }

    matches = new AlignMatch [align_match_vector.size ()];

    for (int i = 0 ; i < matches.length ; ++i) {
      matches[i] = (AlignMatch) align_match_vector.elementAt (i);
    }
  }

  /**
   *  Return an array containing all the AlignMatch objects for this
   *  comparison.
   **/
  public AlignMatch [] getAlignments () {
    return matches;
  }

  /**
   *  Return the maximum score of all the AlignMatch objects in this object.
   **/
  public int getMaximumScore () {
    return max_score;
  }
  
  /**
   *  Return the minimum score of all the AlignMatch objects in this object.
   **/
  public int getMinimumScore () {
    return min_score;
  }

  /**
   *  This is the array of matches created by the constructor.
   **/
  private final AlignMatch [] matches;

  /**
   *  Set by the constructor and returned by getMaximumScore ().
   **/
  private int max_score = -1;

  /**
   *  Set by the constructor and returned by getMinimumScore ().
   **/
  private int min_score = 999999999;
}
